@@ -63,7 +63,7 @@ class DataLogger:
     close()
         close the file (if open) and the connection
     """
-    def __init__(self, url, paths, divider=10, login="", password="", certificate="mcx.cert.pem"):
+    def __init__(self, url, paths, divider=10, login="", password="", certificate="mcx.cert.crt"):
         """
         :param url: the address of the server to connect to in the format wss://[host]:[sub_port]:[req_port]
         :param paths: a list of paths to subscribe to
@@ -172,7 +172,7 @@ class DataLogger:
         Open a file an write the header containing column names for each signal
         """
         if compress:
-            self.file = lzma.open(filename+'.xz', 'wt')
+            self.file = lzma.open(filename+'.xz', 'wt', preset=0)
         else:
             self.file = open(filename, 'w', buffering=1)
         self.file.write("time")
